import { isAny, isInteger, isLength } from './config-validators';
export declare function getDefaultConfig(): {
    readonly cacheSize: 500;
    readonly prefixes: readonly ["sm", "md", "lg", "xl", "2xl", "dark", "motion-safe", "motion-reduce", "first", "last", "odd", "even", "visited", "checked", "group-hover", "group-focus", "focus-within", "hover", "focus", "focus-visible", "active", "disabled"];
    readonly dynamicClasses: {
        readonly decoration: readonly [readonly ["slice", "clone"]];
        readonly box: readonly [readonly ["border", "content"]];
        readonly float: readonly [readonly ["right", "left", "none"]];
        readonly clear: readonly [readonly ["left", "right", "both", "none"]];
        readonly object: readonly [readonly ["contain", "cover", "fill", "none", "scale-down"], readonly ["bottom", "center", "left", "left-bottom", "left-top", "right", "right-bottom", "right-top", "top"]];
        readonly overflow: readonly [readonly ["auto", "hidden", "visible", "scroll"], readonly [{
            readonly x: readonly ["auto", "hidden", "visible", "scroll"];
        }], readonly [{
            readonly y: readonly ["auto", "hidden", "visible", "scroll"];
        }]];
        readonly overscroll: readonly [readonly ["auto", "contain", "none"], readonly [{
            readonly x: readonly ["auto", "contain", "none"];
        }], readonly [{
            readonly y: readonly ["auto", "contain", "none"];
        }]];
        readonly inset: readonly [readonly [{
            readonly x: readonly [typeof isLength];
        }], readonly [{
            readonly y: readonly [typeof isLength];
        }], readonly [typeof isLength]];
        readonly top: readonly [readonly [typeof isLength]];
        readonly right: readonly [readonly [typeof isLength]];
        readonly bottom: readonly [readonly [typeof isLength]];
        readonly left: readonly [readonly [typeof isLength]];
        readonly z: readonly [readonly [typeof isLength]];
        readonly flex: readonly [readonly ["row", "row-reverse", "col", "col-reverse"], readonly ["wrap", "wrap-reverse", "nowrap"], readonly ["1", "auto", "initial", "none"], readonly [{
            readonly grow: readonly ["", typeof isInteger];
        }], readonly [{
            readonly shrink: readonly ["", typeof isInteger];
        }]];
        readonly order: readonly [readonly ["first", "last", "none", typeof isInteger]];
        readonly grid: readonly [readonly [{
            readonly cols: readonly [typeof isAny];
        }], readonly [{
            readonly rows: readonly [typeof isAny];
        }], readonly [{
            readonly flow: readonly ["row", "col", "row-dense", "col-dense"];
        }]];
        readonly col: readonly [readonly ["auto", {
            readonly span: readonly [typeof isInteger];
        }], readonly [{
            readonly start: readonly ["auto", typeof isInteger];
        }], readonly [{
            readonly end: readonly ["auto", typeof isInteger];
        }]];
        readonly row: readonly [readonly ["auto", {
            readonly span: readonly [typeof isInteger];
        }], readonly [{
            readonly start: readonly ["auto", typeof isInteger];
        }], readonly [{
            readonly end: readonly ["auto", typeof isInteger];
        }]];
        readonly auto: readonly [readonly [{
            readonly cols: readonly ["auto", "min", "max", "fr"];
        }], readonly [{
            readonly rows: readonly ["auto", "min", "max", "fr"];
        }]];
        readonly gap: readonly [readonly [{
            readonly x: readonly [typeof isLength];
        }], readonly [{
            readonly y: readonly [typeof isLength];
        }], readonly [typeof isLength]];
        readonly justify: readonly [readonly ["start", "end", "center", "between", "around", "evenly"], readonly [{
            readonly items: readonly ["start", "end", "center", "stretch"];
        }], readonly [{
            readonly self: readonly ["auto", "start", "end", "center", "stretch"];
        }]];
        readonly content: readonly [readonly ["center", "start", "end", "between", "around", "evenly"]];
        readonly items: readonly [readonly ["start", "end", "center", "baseline", "stretch"]];
        readonly self: readonly [readonly ["auto", "start", "end", "center", "stretch"]];
        readonly place: readonly [readonly [{
            readonly content: readonly ["center", "start", "end", "between", "around", "evenly", "stretch"];
        }], readonly [{
            readonly items: readonly ["start", "end", "center", "stretch"];
        }], readonly [{
            readonly self: readonly ["auto", "start", "end", "center", "stretch"];
        }]];
        readonly p: readonly [readonly [typeof isLength]];
        readonly px: readonly [readonly [typeof isLength]];
        readonly py: readonly [readonly [typeof isLength]];
        readonly pt: readonly [readonly [typeof isLength]];
        readonly pr: readonly [readonly [typeof isLength]];
        readonly pb: readonly [readonly [typeof isLength]];
        readonly pl: readonly [readonly [typeof isLength]];
        readonly m: readonly [readonly ["auto", typeof isLength]];
        readonly mx: readonly [readonly ["auto", typeof isLength]];
        readonly my: readonly [readonly ["auto", typeof isLength]];
        readonly mt: readonly [readonly ["auto", typeof isLength]];
        readonly mr: readonly [readonly ["auto", typeof isLength]];
        readonly mb: readonly [readonly ["auto", typeof isLength]];
        readonly ml: readonly [readonly ["auto", typeof isLength]];
        readonly space: readonly [readonly ["x-reverse"], readonly [{
            readonly x: readonly [typeof isLength];
        }], readonly ["y-reverse"], readonly [{
            readonly y: readonly [typeof isLength];
        }]];
        readonly w: readonly [readonly ["auto", "min", "max", typeof isLength]];
        readonly min: readonly [readonly [{
            readonly w: readonly ["full", "min", "max", typeof isLength];
        }], readonly [{
            readonly h: readonly ["full", "screen", typeof isLength];
        }]];
        readonly max: readonly [readonly [{
            readonly w: readonly ["0", "none", "sm", "md", "lg", "xl", "2xl", "3xl", "4xl", "5xl", "6xl", "7xl", "full", "min", "max", "prose", {
                readonly screen: readonly ["sm", "md", "lg", "xl", "2xl"];
            }];
        }], readonly [{
            readonly h: readonly ["full", "screen", typeof isLength];
        }]];
        readonly h: readonly [readonly ["auto", typeof isLength]];
        readonly font: readonly [readonly ["sans", "serif", "mono"], readonly ["thin", "extralight", "light", "normal", "medium", "semibold", "bold", "extrabold", "black"]];
        readonly text: readonly [readonly ["xs", "sm", "md", "lg", "xl", "2xl", "base", "3xl", "4xl", "5xl", "6xl", "7xl", "8xl", "9xl"], readonly ["left", "center", "right", "justify"], readonly [{
            readonly opacity: readonly [typeof isInteger];
        }], readonly [typeof isAny]];
        readonly tracking: readonly [readonly ["tighter", "tight", "normal", "wide", "wider", "widest"]];
        readonly leading: readonly [readonly ["none", "tight", "snug", "normal", "relaxed", "loose", typeof isLength]];
        readonly list: readonly [readonly ["none", "disc", "decimal"], readonly ["inside", "outside"]];
        readonly placeholder: readonly [readonly [{
            readonly opacity: readonly [typeof isInteger];
        }], readonly [typeof isAny]];
        readonly align: readonly [readonly ["baseline", "top", "middle", "bottom", "text-top", "text-bottom"]];
        readonly whitespace: readonly [readonly ["normal", "nowrap", "pre", "pre-line", "pre-wrap"]];
        readonly break: readonly [readonly ["normal", "words", "all"]];
        readonly bg: readonly [readonly ["fixed", "local", "scroll"], readonly [{
            readonly clip: readonly ["border", "padding", "content", "text"];
        }], readonly [{
            readonly opacity: readonly [typeof isInteger];
        }], readonly [{
            readonly origin: readonly ["border", "padding", "content"];
        }], readonly ["bottom", "center", "left", "left-bottom", "left-top", "right", "right-bottom", "right-top", "top"], readonly ["no-repeat", {
            readonly repeat: readonly ["", "x", "y", "round", "space"];
        }], readonly ["auto", "cover", "contain"], readonly ["none", {
            readonly 'gradient-to': readonly ["t", "tr", "r", "br", "b", "bl", "l", "tl"];
        }], readonly [{
            readonly blend: readonly ["normal", "multiply", "screen", "overlay", "darken", "lighten", "color-dodge", "color-burn", "hard-light", "soft-light", "difference", "exclusion", "hue", "saturation", "color", "luminosity"];
        }], readonly [typeof isAny]];
        readonly from: readonly [readonly [typeof isAny]];
        readonly via: readonly [readonly [typeof isAny]];
        readonly to: readonly [readonly [typeof isAny]];
        readonly rounded: readonly [readonly ["none", "", "sm", "md", "lg", "xl", "2xl", "3xl", "full"], readonly [{
            readonly t: readonly ["none", "", "sm", "md", "lg", "xl", "2xl", "3xl", "full"];
        }], readonly [{
            readonly r: readonly ["none", "", "sm", "md", "lg", "xl", "2xl", "3xl", "full"];
        }], readonly [{
            readonly b: readonly ["none", "", "sm", "md", "lg", "xl", "2xl", "3xl", "full"];
        }], readonly [{
            readonly l: readonly ["none", "", "sm", "md", "lg", "xl", "2xl", "3xl", "full"];
        }], readonly [{
            readonly tl: readonly ["none", "", "sm", "md", "lg", "xl", "2xl", "3xl", "full"];
        }], readonly [{
            readonly tr: readonly ["none", "", "sm", "md", "lg", "xl", "2xl", "3xl", "full"];
        }], readonly [{
            readonly br: readonly ["none", "", "sm", "md", "lg", "xl", "2xl", "3xl", "full"];
        }], readonly [{
            readonly bl: readonly ["none", "", "sm", "md", "lg", "xl", "2xl", "3xl", "full"];
        }]];
        readonly border: readonly [readonly [typeof isLength], readonly [{
            readonly t: readonly [typeof isLength];
        }], readonly [{
            readonly r: readonly [typeof isLength];
        }], readonly [{
            readonly b: readonly [typeof isLength];
        }], readonly [{
            readonly l: readonly [typeof isLength];
        }], readonly [{
            readonly opacity: readonly [typeof isInteger];
        }], readonly ["solid", "dashed", "dotted", "double", "none"], readonly ["collapse", "separate"], readonly [typeof isAny]];
        readonly divide: readonly [readonly ["x-reverse"], readonly [{
            readonly x: readonly [typeof isLength];
        }], readonly ["y-reverse"], readonly [{
            readonly y: readonly [typeof isLength];
        }], readonly [{
            readonly opacity: readonly [typeof isInteger];
        }], readonly ["solid", "dashed", "dotted", "double", "none"], readonly [typeof isAny]];
        readonly ring: readonly [readonly ["", typeof isLength], readonly ["inset"], readonly [{
            readonly opacity: readonly [typeof isInteger];
        }], readonly [{
            readonly offset: readonly [typeof isLength];
        }], readonly [{
            readonly offset: readonly [typeof isAny];
        }], readonly [typeof isAny]];
        readonly shadow: readonly [readonly ["", "sm", "md", "lg", "xl", "2xl", "inner", "none"]];
        readonly opacity: readonly [readonly [typeof isInteger]];
        readonly mix: readonly [readonly [{
            readonly blend: readonly ["normal", "multiply", "screen", "overlay", "darken", "lighten", "color-dodge", "color-burn", "hard-light", "soft-light", "difference", "exclusion", "hue", "saturation", "color", "luminosity"];
        }]];
        readonly filter: readonly [readonly ["", "none"]];
        readonly blur: readonly [readonly ["none", "", "sm", "md", "lg", "xl", "2xl", "3xl"]];
        readonly brightness: readonly [readonly [typeof isInteger]];
        readonly contrast: readonly [readonly [typeof isInteger]];
        readonly drop: readonly [readonly [{
            readonly shadow: readonly ["", "sm", "md", "lg", "xl", "2xl", "none"];
        }]];
        readonly grayscale: readonly [readonly ["0", ""]];
        readonly hue: readonly [readonly [{
            readonly rotate: readonly [typeof isInteger];
        }]];
        readonly invert: readonly [readonly ["0", ""]];
        readonly saturate: readonly [readonly [typeof isInteger]];
        readonly sepia: readonly [readonly ["0", ""]];
        readonly backdrop: readonly [readonly [{
            readonly filter: readonly ["", "none"];
        }], readonly [{
            readonly blur: readonly ["none", "", "sm", "md", "lg", "xl", "2xl", "3xl"];
        }], readonly [{
            readonly brightness: readonly [typeof isInteger];
        }], readonly [{
            readonly contrast: readonly [typeof isInteger];
        }], readonly [{
            readonly grayscale: readonly ["0", ""];
        }], readonly [{
            readonly 'hue-rotate': readonly [typeof isInteger];
        }], readonly [{
            readonly invert: readonly ["0", ""];
        }], readonly [{
            readonly opacity: readonly [typeof isInteger];
        }], readonly [{
            readonly saturate: readonly [typeof isInteger];
        }], readonly [{
            readonly sepia: readonly ["0", ""];
        }]];
        readonly table: readonly [readonly ["auto", "fixed"]];
        readonly transition: readonly [readonly ["none", "all", "", "colors", "opacity", "shadow", "transform"]];
        readonly duration: readonly [readonly [typeof isInteger]];
        readonly ease: readonly [readonly ["linear", "in", "out", "in-out"]];
        readonly delay: readonly [readonly [typeof isInteger]];
        readonly animate: readonly [readonly ["none", "spin", "ping", "pulse", "bounce"]];
        readonly transform: readonly [readonly ["", "gpu", "none"], readonly [{
            readonly origin: readonly ["center", "top", "top-right", "right", "bottom-right", "bottom", "bottom-left", "left", "top-left"];
        }]];
        readonly scale: readonly [readonly [typeof isInteger], readonly [{
            readonly x: readonly [typeof isInteger];
        }], readonly [{
            readonly y: readonly [typeof isInteger];
        }]];
        readonly rotate: readonly [readonly [typeof isInteger]];
        readonly translate: readonly [readonly [{
            readonly x: readonly [typeof isLength];
        }], readonly [{
            readonly y: readonly [typeof isLength];
        }]];
        readonly skew: readonly [readonly [{
            readonly x: readonly [typeof isInteger];
        }], readonly [{
            readonly y: readonly [typeof isInteger];
        }]];
        readonly cursor: readonly [readonly ["auto", "default", "pointer", "wait", "text", "move", "help", "not-allowed"]];
        readonly outline: readonly [readonly ["none", "white", "black"]];
        readonly pointer: readonly [readonly [{
            readonly events: readonly ["none", "auto"];
        }]];
        readonly resize: readonly [readonly ["none", "y", "x", ""]];
        readonly select: readonly [readonly ["none", "text", "all", "auto"]];
        readonly stroke: readonly [readonly ["current"], readonly [typeof isLength]];
    };
    readonly standaloneClasses: readonly [readonly ["container"], readonly ["block", "inline-block", "inline", "flex", "inline-flex", "table", "inline-table", "table-caption", "table-cell", "table-column", "table-column-group", "table-footer-group", "table-header-group", "table-row-group", "table-row", "flow-root", "grid", "inline-grid", "contents", "list-item", "hidden"], readonly ["isolate", "isolation-auto"], readonly ["static", "fixed", "absolute", "relative", "sticky"], readonly ["visible", "invisible"], readonly ["antialiased", "subpixel-antialiased"], readonly ["italic", "not-italic"], readonly ["normal-nums", "ordinal", "slashed-zero", "lining-nums", "oldstyle-nums", "tabular-nums", "diagonal-nums", "stacked-fractons"], readonly ["underline", "line-through", "no-underline"], readonly ["uppercase", "lowercase", "capitalize", "normal-case"], readonly ["truncate", "overflow-ellipsis", "overflow-clip"], readonly ["appearance-none"], readonly ["fill-current"], readonly ["sr-only", "not-sr-only"]];
    readonly conflictingGroups: {
        readonly 'dynamicClasses.overflow.0': readonly ["dynamicClasses.overflow.1", "dynamicClasses.overflow.2"];
        readonly 'dynamicClasses.overscroll.0': readonly ["dynamicClasses.overscroll.1", "dynamicClasses.overscroll.2"];
        readonly 'dynamicClasses.inset.2': readonly ["dynamicClasses.inset.0", "dynamicClasses.inset.1", "dynamicClasses.top.0", "dynamicClasses.right.0", "dynamicClasses.bottom.0", "dynamicClasses.left.0"];
        readonly 'dynamicClasses.inset.0': readonly ["dynamicClasses.right.0", "dynamicClasses.left.0"];
        readonly 'dynamicClasses.inset.1': readonly ["dynamicClasses.top.0", "dynamicClasses.bottom.0"];
        readonly 'dynamicClasses.flex.2': readonly ["dynamicClasses.flex.3", "dynamicClasses.flex.4"];
        readonly 'dynamicClasses.col.0': readonly ["dynamicClasses.col.1", "dynamicClasses.col.2"];
        readonly 'dynamicClasses.row.0': readonly ["dynamicClasses.row.1", "dynamicClasses.row.2"];
        readonly 'dynamicClasses.gap.2': readonly ["dynamicClasses.gap.0", "dynamicClasses.gap.1"];
        readonly 'dynamicClasses.p.0': readonly ["dynamicClasses.px.0", "dynamicClasses.py.0", "dynamicClasses.pt.0", "dynamicClasses.pr.0", "dynamicClasses.pb.0", "dynamicClasses.pl.0"];
        readonly 'dynamicClasses.px.0': readonly ["dynamicClasses.pr.0", "dynamicClasses.pl.0"];
        readonly 'dynamicClasses.py.0': readonly ["dynamicClasses.pt.0", "dynamicClasses.pb.0"];
        readonly 'dynamicClasses.m.0': readonly ["dynamicClasses.mx.0", "dynamicClasses.my.0", "dynamicClasses.mt.0", "dynamicClasses.mr.0", "dynamicClasses.mb.0", "dynamicClasses.ml.0"];
        readonly 'dynamicClasses.mx.0': readonly ["dynamicClasses.mr.0", "dynamicClasses.ml.0"];
        readonly 'dynamicClasses.my.0': readonly ["dynamicClasses.mt.0", "dynamicClasses.mb.0"];
        readonly 'dynamicClasses.text.0': readonly ["dynamicClasses.leading.0"];
        readonly 'dynamicClasses.rounded.0': readonly ["dynamicClasses.rounded.1", "dynamicClasses.rounded.2", "dynamicClasses.rounded.3", "dynamicClasses.rounded.4", "dynamicClasses.rounded.5", "dynamicClasses.rounded.6", "dynamicClasses.rounded.7", "dynamicClasses.rounded.8"];
        readonly 'dynamicClasses.rounded.1': readonly ["dynamicClasses.rounded.5", "dynamicClasses.rounded.6"];
        readonly 'dynamicClasses.rounded.2': readonly ["dynamicClasses.rounded.6", "dynamicClasses.rounded.7"];
        readonly 'dynamicClasses.rounded.3': readonly ["dynamicClasses.rounded.7", "dynamicClasses.rounded.8"];
        readonly 'dynamicClasses.rounded.4': readonly ["dynamicClasses.rounded.5", "dynamicClasses.rounded.8"];
        readonly 'dynamicClasses.border.0': readonly ["dynamicClasses.border.1", "dynamicClasses.border.2", "dynamicClasses.border.3", "dynamicClasses.border.4"];
        readonly 'dynamicClasses.ring.0': readonly ["dynamicClasses.ring.0", "dynamicClasses.shadow.0"];
        readonly 'dynamicClasses.shadow.0': readonly ["dynamicClasses.ring.0", "dynamicClasses.shadow.0"];
    };
};
